@@ -7,6 +7,7 @@ from collections import Counter, defaultdict
 from pathlib import Path
 import click
 import boto3  # type: ignore
+import logging
 import yaml
 from django.db import transaction, connection  # type: ignore
 from ..utils import abbr_to_jid
@@ -29,7 +30,14 @@ from ..utils.people.to_database import (
     CancelTransaction,
 )
 from ..utils.people.merge import process_scrape_dir, incoming_merge
+from ..utils.instrument import Instrumentation
 
+stats = Instrumentation()
+
+logging.getLogger('boto3').setLevel(logging.WARNING)
+logging.getLogger('botocore').setLevel(logging.WARNING)
+logging.getLogger('s3transfer').setLevel(logging.WARNING)
+logging.getLogger('urllib3').setLevel(logging.WARNING)
 
 OPTIONAL_FIELD_SET = {
     "sort_name",
@@ -175,7 +183,11 @@ def write_csv(files: list[Path], jurisdiction_id: str, output_filename: str) ->
         out.writeheader()
 
         for filename in files:
-            person: Person = Person.load_yaml(filename)
+            try:
+                person: Person = Person.load_yaml(filename)
+            except Exception as e:
+                click.secho(f"Cannot load {filename} :: {e}")
+                raise
 
             # current party
             for p_role in person.party:
@@ -721,8 +733,8 @@ def merge(abbr: str, input_dir: str, retirement: str, reset_offices: bool) -> No
     """
     Convert scraped JSON in INPUT_DIR to YAML files for this repo.
     """
+    stats.send_counter("people_scrapes_total", 1, {"jurisdiction": abbr})
     jurisdiction_id = abbr_to_jid(abbr)
-
     new_people = process_scrape_dir(Path(input_dir), jurisdiction_id)
 
     existing_people: list[Person] = []
@@ -733,6 +745,13 @@ def merge(abbr: str, input_dir: str, retirement: str, reset_offices: bool) -> No
     ):
         existing_people.append(Person.load_yaml(filename))
 
+    stats.send_gauge(
+        "new_people_discovered", len(existing_people), {"jurisdiction": abbr}
+    )
+    stats.send_gauge(
+        "existing_people_discovered", len(new_people), {"jurisdiction": abbr}
+    )
+
     click.secho(
         f"analyzing {len(existing_people)} existing people and {len(new_people)} scraped"
     )
@@ -741,6 +760,9 @@ def merge(abbr: str, input_dir: str, retirement: str, reset_offices: bool) -> No
         abbr, existing_people, new_people, retirement, reset_offices
     )
     click.secho(f"{len(unmatched)} people were unmatched")
+    stats.send_gauge("people_unmatched", len(unmatched), {"jurisdiction": abbr})
+    stats.send_last_run("people_merge_last_run_time", {"jurisdiction": abbr})
+    stats.close()
 
 
 if __name__ == "__main__":
