@@ -6,9 +6,9 @@ from .people_orgs import (
     Person,
     PersonIdentifier,
     PersonName,
-    PersonContactDetail,
     PersonLink,
     PersonSource,
+    PersonOffice,
     Post,
     Membership,
 )
