@@ -59,7 +59,7 @@ class Organization(OCDBase):
                 break
 
     def get_current_members(self):
-        """ return all Person objects w/ current memberships to org """
+        """return all Person objects w/ current memberships to org"""
         today = datetime.date.today().isoformat()
 
         return Person.objects.filter(
@@ -284,38 +284,35 @@ class PersonName(RelatedBase):
         return "{} ({})".format(self.name, self.note)
 
 
-class PersonContactDetail(RelatedBase):
+OFFICE_CHOICES = (
+    ("district", "District Office"),
+    ("capitol", "Capitol Office"),
+    ("primary", "Primary Office"),
+)
+
+
+class PersonOffice(RelatedBase):
     """
-    Contact information for a Person.
+    Office for a Person.
     """
 
-    type = models.CharField(
-        max_length=50,
-        choices=common.CONTACT_TYPE_CHOICES,
-        help_text="The type of Contact being defined.",
-    )
-    value = models.CharField(
-        max_length=300,
-        help_text="The content of the Contact information like a phone number or address.",
-    )
-    note = models.CharField(
-        max_length=300,
-        blank=True,
-        help_text="A short, optional note about the Contact value.",
-    )
+    classification = models.CharField(max_length=20, choices=OFFICE_CHOICES)
+    address = models.CharField(max_length=300, blank=True, default="")
+    voice = models.CharField(max_length=30, blank=True, default="")
+    fax = models.CharField(max_length=30, blank=True, default="")
+    name = models.CharField(max_length=200, blank=True, default="")
 
-    person = models.ForeignKey(
-        Person,
-        related_name="contact_details",
-        on_delete=models.CASCADE,
-        help_text="A link to the Person connected to this contact.",
-    )
+    @property
+    def display_name(self):
+        return self.name or self.get_classification_display()
+
+    person = models.ForeignKey(Person, related_name="offices", on_delete=models.CASCADE)
 
     class Meta:
-        db_table = "opencivicdata_personcontactdetail"
+        db_table = "openstates_personoffice"
 
     def __str__(self):
-        return "{}: {}".format(self.get_type_display(), self.value)
+        return f"{self.person} {self.display_name}"
 
 
 class PersonLink(LinkBase):
