@@ -64,15 +64,9 @@ VT = State(
                 1,
             ),
             District(
-                "Bennington-2-1",
+                "Bennington-2",
                 "lower",
-                "ocd-division/country:us/state:vt/sldl:bennington-2-1",
-                2,
-            ),
-            District(
-                "Bennington-2-2",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:bennington-2-2",
+                "ocd-division/country:us/state:vt/sldl:bennington-2",
                 2,
             ),
             District(
@@ -87,6 +81,12 @@ VT = State(
                 "ocd-division/country:us/state:vt/sldl:bennington-4",
                 2,
             ),
+            District(
+                "Bennington-5",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:bennington-5",
+                2,
+            ),
             District(
                 "Bennington-Rutland",
                 "lower",
@@ -111,24 +111,156 @@ VT = State(
                 "ocd-division/country:us/state:vt/sldl:caledonia-3",
                 2,
             ),
-            District(
-                "Caledonia-4",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:caledonia-4",
-                2,
-            ),
             District(
                 "Caledonia-Washington",
                 "lower",
                 "ocd-division/country:us/state:vt/sldl:caledonia-washington",
                 1,
             ),
+            District(
+                "Caledonia-Essex",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:caledonia-essex",
+                2,
+            ),
+            District(
+                "Chittenden-19",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-19",
+                2,
+            ),
             District(
                 "Chittenden-10",
                 "lower",
                 "ocd-division/country:us/state:vt/sldl:chittenden-10",
+                1,
+            ),
+            District(
+                "Chittenden-4",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-4",
+                1,
+            ),
+            District(
+                "Chittenden-5",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-5",
+                1,
+            ),
+            District(
+                "Chittenden-13",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-13",
                 2,
             ),
+            District(
+                "Chittenden-14",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-14",
+                2,
+            ),
+            District(
+                "Chittenden-15",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-15",
+                2,
+            ),
+            District(
+                "Chittenden-16",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-16",
+                2,
+            ),
+            District(
+                "Chittenden-17",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-17",
+                1,
+            ),
+            District(
+                "Windsor-Addison",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:windsor-addison",
+                1,
+            ),
+            District(
+                "Washington-Orange",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:washington-orange",
+                2,
+            ),
+            District(
+                "Chittenden-Franklin",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-franklin",
+                2,
+            ),
+            District(
+                "Chittenden-8",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-8",
+                1,
+            ),
+            District(
+                "Chittenden-9",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-9",
+                1,
+            ),
+            District(
+                "Chittenden-12",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-12",
+                1,
+            ),
+            District(
+                "Chittenden-11",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-11",
+                1,
+            ),
+            District(
+                "Chittenden-18",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-18",
+                2,
+            ),
+            District(
+                "Chittenden-24",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-24",
+                1,
+            ),
+            District(
+                "Chittenden-23",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-23",
+                2,
+            ),
+            District(
+                "Chittenden-22",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-22",
+                2,
+            ),
+            District(
+                "Chittenden-21",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-21",
+                2,
+            ),
+            District(
+                "Chittenden-20",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-20",
+                2,
+            ),
+            District(
+                "Chittenden-25",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:chittenden-25",
+                1,
+            ),
             District(
                 "Chittenden-1",
                 "lower",
@@ -148,125 +280,17 @@ VT = State(
                 2,
             ),
             District(
-                "Chittenden-4-1",
+                "Chittenden-6",
                 "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-4-1",
+                "ocd-division/country:us/state:vt/sldl:chittenden-6",
                 1,
             ),
             District(
-                "Chittenden-4-2",
+                "Chittenden-7",
                 "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-4-2",
+                "ocd-division/country:us/state:vt/sldl:chittenden-7",
                 1,
             ),
-            District(
-                "Chittenden-5-1",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-5-1",
-                1,
-            ),
-            District(
-                "Chittenden-5-2",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-5-2",
-                1,
-            ),
-            District(
-                "Chittenden-6-1",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-6-1",
-                2,
-            ),
-            District(
-                "Chittenden-6-2",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-6-2",
-                1,
-            ),
-            District(
-                "Chittenden-6-3",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-6-3",
-                2,
-            ),
-            District(
-                "Chittenden-6-4",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-6-4",
-                2,
-            ),
-            District(
-                "Chittenden-6-5",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-6-5",
-                2,
-            ),
-            District(
-                "Chittenden-6-6",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-6-6",
-                1,
-            ),
-            District(
-                "Chittenden-6-7",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-6-7",
-                2,
-            ),
-            District(
-                "Chittenden-7-1",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-7-1",
-                1,
-            ),
-            District(
-                "Chittenden-7-2",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-7-2",
-                1,
-            ),
-            District(
-                "Chittenden-7-3",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-7-3",
-                1,
-            ),
-            District(
-                "Chittenden-7-4",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-7-4",
-                1,
-            ),
-            District(
-                "Chittenden-8-1",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-8-1",
-                2,
-            ),
-            District(
-                "Chittenden-8-2",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-8-2",
-                2,
-            ),
-            District(
-                "Chittenden-8-3",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-8-3",
-                1,
-            ),
-            District(
-                "Chittenden-9-1",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-9-1",
-                2,
-            ),
-            District(
-                "Chittenden-9-2",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:chittenden-9-2",
-                2,
-            ),
             District(
                 "Essex-Caledonia",
                 "lower",
@@ -274,16 +298,22 @@ VT = State(
                 1,
             ),
             District(
-                "Essex-Caledonia-Orleans",
+                "Essex-Orleans",
                 "lower",
-                "ocd-division/country:us/state:vt/sldl:essex-caledonia-orleans",
+                "ocd-division/country:us/state:vt/sldl:essex-orleans",
+                1,
+            ),
+            District(
+                "Franklin-8",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:franklin-8",
                 1,
             ),
             District(
                 "Franklin-1",
                 "lower",
                 "ocd-division/country:us/state:vt/sldl:franklin-1",
-                1,
+                2,
             ),
             District(
                 "Franklin-2",
@@ -292,15 +322,9 @@ VT = State(
                 1,
             ),
             District(
-                "Franklin-3-1",
+                "Franklin-3",
                 "lower",
-                "ocd-division/country:us/state:vt/sldl:franklin-3-1",
-                2,
-            ),
-            District(
-                "Franklin-3-2",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:franklin-3-2",
+                "ocd-division/country:us/state:vt/sldl:franklin-3",
                 1,
             ),
             District(
@@ -358,11 +382,14 @@ VT = State(
                 2,
             ),
             District(
-                "Orange-1", "lower", "ocd-division/country:us/state:vt/sldl:orange-1", 2
+                "Orange-1", "lower", "ocd-division/country:us/state:vt/sldl:orange-1", 1
             ),
             District(
                 "Orange-2", "lower", "ocd-division/country:us/state:vt/sldl:orange-2", 1
             ),
+            District(
+                "Orange-3", "lower", "ocd-division/country:us/state:vt/sldl:orange-3", 1
+            ),
             District(
                 "Orange-Caledonia",
                 "lower",
@@ -379,25 +406,31 @@ VT = State(
                 "Orleans-1",
                 "lower",
                 "ocd-division/country:us/state:vt/sldl:orleans-1",
-                2,
+                1,
             ),
             District(
                 "Orleans-2",
                 "lower",
                 "ocd-division/country:us/state:vt/sldl:orleans-2",
-                2,
+                1,
             ),
             District(
-                "Orleans-Caledonia",
+                "Orleans-3",
                 "lower",
-                "ocd-division/country:us/state:vt/sldl:orleans-caledonia",
-                2,
+                "ocd-division/country:us/state:vt/sldl:orleans-3",
+                1,
+            ),
+            District(
+                "Orleans-4",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:orleans-4",
+                1,
             ),
             District(
                 "Orleans-Lamoille",
                 "lower",
                 "ocd-division/country:us/state:vt/sldl:orleans-lamoille",
-                1,
+                2,
             ),
             District(
                 "Rutland-1",
@@ -415,7 +448,7 @@ VT = State(
                 "Rutland-3",
                 "lower",
                 "ocd-division/country:us/state:vt/sldl:rutland-3",
-                2,
+                1,
             ),
             District(
                 "Rutland-4",
@@ -424,34 +457,16 @@ VT = State(
                 1,
             ),
             District(
-                "Rutland-5-1",
+                "Rutland-5",
                 "lower",
-                "ocd-division/country:us/state:vt/sldl:rutland-5-1",
-                1,
-            ),
-            District(
-                "Rutland-5-2",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:rutland-5-2",
-                1,
-            ),
-            District(
-                "Rutland-5-3",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:rutland-5-3",
-                1,
-            ),
-            District(
-                "Rutland-5-4",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:rutland-5-4",
+                "ocd-division/country:us/state:vt/sldl:rutland-5",
                 1,
             ),
             District(
                 "Rutland-6",
                 "lower",
                 "ocd-division/country:us/state:vt/sldl:rutland-6",
-                2,
+                1,
             ),
             District(
                 "Rutland-Bennington",
@@ -460,15 +475,15 @@ VT = State(
                 1,
             ),
             District(
-                "Rutland-Windsor-1",
+                "Rutland-Windsor",
                 "lower",
-                "ocd-division/country:us/state:vt/sldl:rutland-windsor-1",
+                "ocd-division/country:us/state:vt/sldl:rutland-windsor",
                 1,
             ),
             District(
-                "Rutland-Windsor-2",
+                "Windsor-Windham",
                 "lower",
-                "ocd-division/country:us/state:vt/sldl:rutland-windsor-2",
+                "ocd-division/country:us/state:vt/sldl:windsor-windham",
                 1,
             ),
             District(
@@ -507,12 +522,6 @@ VT = State(
                 "ocd-division/country:us/state:vt/sldl:washington-6",
                 1,
             ),
-            District(
-                "Washington-7",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:washington-7",
-                2,
-            ),
             District(
                 "Washington-Chittenden",
                 "lower",
@@ -526,21 +535,27 @@ VT = State(
                 1,
             ),
             District(
-                "Windham-2-1",
+                "Windham-2",
                 "lower",
-                "ocd-division/country:us/state:vt/sldl:windham-2-1",
+                "ocd-division/country:us/state:vt/sldl:windham-2",
                 1,
             ),
             District(
-                "Windham-2-2",
+                "Windham-9",
                 "lower",
-                "ocd-division/country:us/state:vt/sldl:windham-2-2",
+                "ocd-division/country:us/state:vt/sldl:windham-9",
                 1,
             ),
             District(
-                "Windham-2-3",
+                "Windham-8",
                 "lower",
-                "ocd-division/country:us/state:vt/sldl:windham-2-3",
+                "ocd-division/country:us/state:vt/sldl:windham-8",
+                1,
+            ),
+            District(
+                "Windham-7",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:windham-7",
                 1,
             ),
             District(
@@ -553,7 +568,7 @@ VT = State(
                 "Windham-4",
                 "lower",
                 "ocd-division/country:us/state:vt/sldl:windham-4",
-                2,
+                1,
             ),
             District(
                 "Windham-5",
@@ -568,13 +583,7 @@ VT = State(
                 1,
             ),
             District(
-                "Windham-Bennington",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:windham-bennington",
-                1,
-            ),
-            District(
-                "Windham-Bennington-Windsor",
+                "Windham-Windsor-Bennington",
                 "lower",
                 "ocd-division/country:us/state:vt/sldl:windham-bennington-windsor",
                 1,
@@ -592,35 +601,59 @@ VT = State(
                 1,
             ),
             District(
-                "Windsor-3-1",
+                "Windsor-3",
                 "lower",
-                "ocd-division/country:us/state:vt/sldl:windsor-3-1",
-                1,
-            ),
-            District(
-                "Windsor-3-2",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:windsor-3-2",
+                "ocd-division/country:us/state:vt/sldl:windsor-3",
                 2,
             ),
             District(
-                "Windsor-4-1",
+                "Windsor-4",
                 "lower",
-                "ocd-division/country:us/state:vt/sldl:windsor-4-1",
+                "ocd-division/country:us/state:vt/sldl:windsor-4",
                 1,
             ),
-            District(
-                "Windsor-4-2",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:windsor-4-2",
-                2,
-            ),
             District(
                 "Windsor-5",
                 "lower",
                 "ocd-division/country:us/state:vt/sldl:windsor-5",
                 1,
             ),
+            District(
+                "Windsor-6",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:windsor-6",
+                2,
+            ),
+            District(
+                "Rutland-11",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:rutland-11",
+                1,
+            ),
+            District(
+                "Rutland-7",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:rutland-7",
+                1,
+            ),
+            District(
+                "Rutland-8",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:rutland-8",
+                1,
+            ),
+            District(
+                "Rutland-10",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:rutland-10",
+                1,
+            ),
+            District(
+                "Rutland-9",
+                "lower",
+                "ocd-division/country:us/state:vt/sldl:rutland-9",
+                1,
+            ),
             District(
                 "Windsor-Orange-1",
                 "lower",
@@ -633,12 +666,6 @@ VT = State(
                 "ocd-division/country:us/state:vt/sldl:windsor-orange-2",
                 2,
             ),
-            District(
-                "Windsor-Rutland",
-                "lower",
-                "ocd-division/country:us/state:vt/sldl:windsor-rutland",
-                1,
-            ),
         ],
     ),
     upper=Chamber(
@@ -661,19 +688,31 @@ VT = State(
                 "Caledonia",
                 "upper",
                 "ocd-division/country:us/state:vt/sldu:caledonia",
-                2,
+                1,
             ),
             District(
-                "Chittenden",
+                "Chittenden Central",
                 "upper",
-                "ocd-division/country:us/state:vt/sldu:chittenden",
-                6,
+                "ocd-division/country:us/state:vt/sldu:chittenden-central",
+                3,
             ),
             District(
-                "Essex-Orleans",
+                "Chittenden North",
                 "upper",
-                "ocd-division/country:us/state:vt/sldu:essex-orleans",
-                2,
+                "ocd-division/country:us/state:vt/sldu:chittenden-north",
+                1,
+            ),
+            District(
+                "Chittenden Southeast",
+                "upper",
+                "ocd-division/country:us/state:vt/sldu:chittenden-southeast",
+                3,
+            ),
+            District(
+                "Orleans", "upper", "ocd-division/country:us/state:vt/sldu:orleans", 1
+            ),
+            District(
+                "Essex", "upper", "ocd-division/country:us/state:vt/sldu:essex", 1
             ),
             District(
                 "Franklin", "upper", "ocd-division/country:us/state:vt/sldu:franklin", 2
