@@ -1,14 +1,14 @@
-import os
+import boto3  # noqa
+import datetime
 import importlib
 import json
-import uuid
-import logging
-import datetime
-from collections import defaultdict, OrderedDict
-
 import jsonschema
-from jsonschema import Draft3Validator, FormatChecker
+import logging
+import os
 import scrapelib
+import uuid
+from collections import defaultdict, OrderedDict
+from jsonschema import Draft3Validator, FormatChecker
 
 from .. import utils, settings
 from ..exceptions import ScrapeError, ScrapeValueError, EmptyScrape
@@ -70,13 +70,20 @@ class Scraper(scrapelib.Scraper):
     """Base class for all scrapers"""
 
     def __init__(
-        self, jurisdiction, datadir, *, strict_validation=True, fastmode=False
+        self,
+        jurisdiction,
+        datadir,
+        *,
+        strict_validation=True,
+        fastmode=False,
+        realtime=False,
     ):
         super(Scraper, self).__init__()
 
         # set options
         self.jurisdiction = jurisdiction
         self.datadir = datadir
+        self.realtime = realtime
 
         # scrapelib setup
         self.timeout = settings.SCRAPELIB_TIMEOUT
@@ -85,6 +92,9 @@ class Scraper(scrapelib.Scraper):
         self.retry_wait_seconds = settings.SCRAPELIB_RETRY_WAIT_SECONDS
         self.verify = settings.SCRAPELIB_VERIFY
 
+        # output
+        self.output_file_path = None
+
         # caching
         if settings.CACHE_DIR:
             self.cache_storage = scrapelib.FileCache(settings.CACHE_DIR)
@@ -114,6 +124,36 @@ class Scraper(scrapelib.Scraper):
             handler = importlib.import_module(modname)
             self.scrape_output_handler = handler.Handler(self)
 
+    def push_to_queue(self):
+        """Push this output to the sqs for realtime imports."""
+
+        # Create SQS client
+        sqs = boto3.client("sqs")
+
+        queue_url = settings.SQS_QUEUE_URL
+        bucket = settings.S3_REALTIME_BASE.replace("s3://", "")
+
+        message_body = json.dumps(
+            {
+                "file_path": self.output_file_path,
+                "bucket": bucket,
+                "jurisdiction_id": self.jurisdiction.jurisdiction_id,
+                "jurisdiction_name": self.jurisdiction.name,
+            }
+        )
+
+        # Send message to SQS queue
+        response = sqs.send_message(
+            QueueUrl=queue_url,
+            DelaySeconds=10,
+            MessageAttributes={
+                "Title": {"DataType": "String", "StringValue": "S3 Output Path"},
+                "Author": {"DataType": "String", "StringValue": "Open States"},
+            },
+            MessageBody=message_body,
+        )
+        self.info(f"Message ID: {response['MessageId']}")
+
     def save_object(self, obj):
         """
         Save object to disk as JSON.
@@ -123,9 +163,9 @@ class Scraper(scrapelib.Scraper):
         clean_whitespace(obj)
         obj.pre_save(self.jurisdiction.jurisdiction_id)
 
-        filename = "{0}_{1}.json".format(obj._type, obj._id).replace("/", "-")
+        filename = f"{obj._type}_{obj._id}.json".replace("/", "-")
+        self.info(f"save {obj._type} {obj} as {filename}")
 
-        self.info("save %s %s as %s", obj._type, obj, filename)
         self.debug(
             json.dumps(
                 OrderedDict(sorted(obj.as_dict().items())),
@@ -138,8 +178,37 @@ class Scraper(scrapelib.Scraper):
         self.output_names[obj._type].add(filename)
 
         if self.scrape_output_handler is None:
-            with open(os.path.join(self.datadir, filename), "w") as f:
-                json.dump(obj.as_dict(), f, cls=utils.JSONEncoderPlus)
+            file_path = os.path.join(self.datadir, filename)
+
+            # Remove redundant prefix
+            try:
+                upload_file_path = file_path[
+                    file_path.index("_data") + len("_data") + 1 :
+                ]
+            except Exception:
+                upload_file_path = file_path
+
+            if self.realtime:
+                self.output_file_path = str(upload_file_path)
+
+                s3 = boto3.client("s3")
+                bucket = settings.S3_REALTIME_BASE.removeprefix("s3://")
+
+                s3.put_object(
+                    Body=json.dumps(
+                        OrderedDict(sorted(obj.as_dict().items())),
+                        cls=utils.JSONEncoderPlus,
+                        separators=(",", ": "),
+                    ),
+                    Bucket=bucket,
+                    Key=self.output_file_path,
+                )
+
+                self.push_to_queue()
+            else:
+                with open(file_path, "w") as f:
+                    json.dump(obj.as_dict(), f, cls=utils.JSONEncoderPlus)
+
         else:
             self.scrape_output_handler.handle(obj)
 
@@ -250,6 +319,7 @@ class BaseModel(object):
         if schema is None:
             schema = self._schema
 
+        # this code copied to openstates/cli/validate - maybe update it if changes here :)
         type_checker = Draft3Validator.TYPE_CHECKER.redefine(
             "datetime", lambda c, d: isinstance(d, (datetime.date, datetime.datetime))
         )
