@@ -9,7 +9,7 @@ _mi_bill_id_re = re.compile(r"(SJR|HJR)\s*([A-Z]+)\s*$")
 _whitespace_re = re.compile(r"\s+")
 
 
-def fix_bill_id(bill_id):
+def fix_bill_id(bill_id: str) -> str:
     bill_id = bill_id.upper()
     # special case for MI Joint Resolutions in format "(H|S)JR {letters}"
     if _mi_bill_id_re.match(bill_id):
@@ -17,5 +17,5 @@ def fix_bill_id(bill_id):
     return _bill_id_re.sub(r"\1 \2", bill_id, 1).strip()
 
 
-def collapse_whitespace(value):
+def collapse_whitespace(value: str) -> str:
     return _whitespace_re.sub(" ", value)
